@@ -19,7 +19,6 @@
 #include <QMutex>
 #include <QWaitCondition>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QScreen>
 #include <QChar>
 #include <QBuffer>
@@ -42,10 +41,6 @@
 #include "dbusnotifier.h"
 #endif
 
-#ifdef SG_EXT_UPLOADS
-#include "modules/uploader/moduleuploader.h"
-#endif
-
 Core* Core::corePtr = nullptr;
 
 Core::Core()
@@ -60,23 +55,23 @@ Core::Core()
     _selector = nullptr;
     _firstScreen = true;
 
-    _cmdLine.setApplicationDescription("ScreenGrab " + tr("is a crossplatform application for fast creating screenshots of your desktop."));
+    _cmdLine.setApplicationDescription(QStringLiteral("ScreenGrab ") + tr("is a crossplatform application for fast creating screenshots of your desktop."));
     _cmdLine.addHelpOption();
     _cmdLine.addVersionOption();
 
-    QCommandLineOption optFullScreen(QStringList() << "f" << "fullscreen", tr("Take a fullscreen screenshot"));
+    QCommandLineOption optFullScreen(QStringList() << QStringLiteral("f") << QStringLiteral("fullscreen"), tr("Take a fullscreen screenshot"));
     _cmdLine.addOption(optFullScreen);
     _screenTypeOpts.append(optFullScreen);
 
-    QCommandLineOption optActiveWnd(QStringList() << "a" << "active", tr("Take a screenshot of the active window"));
+    QCommandLineOption optActiveWnd(QStringList() << QStringLiteral("a") << QStringLiteral("active"), tr("Take a screenshot of the active window"));
     _cmdLine.addOption(optActiveWnd);
     _screenTypeOpts.append(optActiveWnd);
 
-    QCommandLineOption optSelectedRect(QStringList() << "r" << "region", tr("Take a screenshot of a selection of the screen"));
+    QCommandLineOption optSelectedRect(QStringList() << QStringLiteral("r") << QStringLiteral("region"), tr("Take a screenshot of a selection of the screen"));
     _cmdLine.addOption(optSelectedRect);
     _screenTypeOpts.append(optSelectedRect);
 
-    QCommandLineOption optRunMinimized(QStringList() << "m" << "minimized", tr("Run the application with a hidden main window"));
+    QCommandLineOption optRunMinimized(QStringList() << QStringLiteral("m") << QStringLiteral("minimized"), tr("Run the application with a hidden main window"));
     _cmdLine.addOption(optRunMinimized);
 
     sleep(250);
@@ -112,7 +107,7 @@ void Core::initWindow(const QString& ipcMessage)
         _wnd = new MainWindow;
         _wnd->setConfig(_conf);
         _wnd->updateModulesActions(_modules.generateModulesActions());
-        _wnd->updateModulesenus(_modules.generateModulesMenus());
+        _wnd->updateModulesMenus(_modules.generateModulesMenus());
 
         screenShot(true); // first screenshot
 
@@ -175,6 +170,21 @@ void Core::setScreen()
 
 }
 
+void Core::getFullScreenPixmap(QScreen* screen)
+{
+    const auto siblings = screen->virtualSiblings();
+    if (siblings.size() == 1)
+        *_pixelMap = screen->grabWindow(0); // 0 for the entire screen
+    else
+    { // consider all siblings
+        QPixmap pix = QPixmap(screen->virtualSize());
+        pix.fill(Qt::transparent);
+        QPainter painter(&pix);
+        for (const auto& sc : siblings)
+            painter.drawPixmap(sc->geometry().topLeft(), sc->grabWindow(0));
+        *_pixelMap = pix;
+    }
+}
 
 // get screenshot
 void Core::screenShot(bool first)
@@ -190,10 +200,10 @@ void Core::screenShot(bool first)
     {
     case Core::FullScreen:
     {
-        const QList<QScreen *> screens = qApp->screens();
-        const QDesktopWidget *desktop = QApplication::desktop();
-        const int screenNum = desktop->screenNumber(QCursor::pos());
-        *_pixelMap = screens[screenNum]->grabWindow(desktop->winId());
+        auto screen = QGuiApplication::screenAt(QCursor::pos());
+        if (screen == nullptr)
+            screen = QGuiApplication::screens().at(0);
+        getFullScreenPixmap(screen);
         grabCursor(0, 0);
 
         checkAutoSave(first);
@@ -220,7 +230,7 @@ void Core::screenShot(bool first)
         break;
     }
     default:
-        *_pixelMap = QPixmap::grabWindow(QApplication::desktop()->winId());
+        getFullScreenPixmap(QGuiApplication::primaryScreen());
         break;
     }
 
@@ -247,9 +257,9 @@ void Core::checkAutoSave(bool first)
 
 void Core::getActiveWindow() // called only with window screenshots
 {
-    const QList<QScreen *> screens = qApp->screens();
-    const QDesktopWidget *desktop = QApplication::desktop();
-    const int screenNum = desktop->screenNumber(QCursor::pos());
+    auto screen = QGuiApplication::screenAt(QCursor::pos());
+    if (screen == nullptr)
+        screen = QGuiApplication::screens().at(0);
 
     WId wnd = KWindowSystem::activeWindow();
 
@@ -279,23 +289,22 @@ void Core::getActiveWindow() // called only with window screenshots
     if (invalid)
     {
         qWarning() << "Could not take a window screenshot.";
-        *_pixelMap = screens[screenNum]->grabWindow(desktop->winId());
+        *_pixelMap = screen->grabWindow(0);
         return;
     }
 
     // no decorations option is selected
     if (_conf->getNoDecoration())
     {
-        *_pixelMap = screens[screenNum]->grabWindow(wnd);
+        *_pixelMap = screen->grabWindow(wnd);
         return;
     }
 
     QRect geometry = info.frameGeometry();
-    *_pixelMap = screens[screenNum]->grabWindow(QApplication::desktop()->winId(),
-                                     geometry.x(),
-                                     geometry.y(),
-                                     geometry.width(),
-                                                geometry.height());
+    // The offscreen part of the window will appear as a black area in the screenshot.
+    // Until a better method is found, the offscreen area is ignored here.
+    QRect r = screen->virtualGeometry().intersected(geometry);
+    *_pixelMap = screen->grabWindow(0, r.x(), r.y(), r.width(), r.height());
     grabCursor(geometry.x(), geometry.y());
 }
 
@@ -326,13 +335,13 @@ QString Core::getSaveFilePath(const QString &format)
         QDir dir(_conf->getSaveDir());
         const QString filePath = dir.filePath(_conf->getSaveFileName());
         if (_conf->getDateTimeInFilename())
-            initPath = filePath + "-" + getDateTimeFileName() + "." + format;
+            initPath = filePath + QStringLiteral("-") + getDateTimeFileName() + QStringLiteral(".") + format;
         else
         {
             if (_conf->getScrNum() != 0)
-                initPath = filePath + _conf->getScrNumStr() + "." + format;
+                initPath = filePath + _conf->getScrNumStr() + QStringLiteral(".") + format;
             else
-                initPath = filePath + "." + format;
+                initPath = filePath + QStringLiteral(".") + format;
         }
     } while (checkExsistFile(initPath));
 
@@ -354,7 +363,7 @@ QString Core::getDateTimeFileName()
     QString currentDateTime = QDateTime::currentDateTime().toString(_conf->getDateTimeTpl());
 
     if (currentDateTime == _conf->getLastSaveDate().toString(_conf->getDateTimeTpl()) && _conf->getScrNum() != 0)
-        currentDateTime += "-" + _conf->getScrNumStr();
+        currentDateTime += QStringLiteral("-") + _conf->getScrNumStr();
     else
         _conf->resetScrNum();
 
@@ -380,7 +389,7 @@ QString Core::getTempFilename(const QString& format)
     _tempFilename = QUuid::createUuid().toString();
     int size = _tempFilename.size() - 2;
     _tempFilename = _tempFilename.mid(1, size).left(8);
-    _tempFilename = QDir::tempPath() + QDir::separator() + "screenshot-" + _tempFilename + "." + format;
+    _tempFilename = QDir::tempPath() + QDir::separator() + QStringLiteral("screenshot-") + _tempFilename + QStringLiteral(".") + format;
     return _tempFilename;
 }
 
@@ -396,14 +405,14 @@ void Core::killTempFile()
 bool Core::writeScreen(QString& fileName, QString& format, bool tmpScreen)
 {
     // adding extension format
-    if (!fileName.contains("." + format))
-        fileName.append("." + format);
+    if (!fileName.contains(QStringLiteral(".") + format))
+        fileName.append(QStringLiteral(".") + format);
 
-    // saving temp file (for uploader module)
+    // saving temp file
     if (tmpScreen)
     {
         if (!fileName.isEmpty())
-            return _pixelMap->save(fileName, format.toLatin1(), _conf->getImageQuality());
+            return _pixelMap->save(fileName, format.toLatin1().constData(), _conf->getImageQuality());
         else
             return false;
     }
@@ -412,10 +421,10 @@ bool Core::writeScreen(QString& fileName, QString& format, bool tmpScreen)
     bool saved = false;
     if (!fileName.isEmpty())
     {
-        if (format == "jpg")
-            saved = _pixelMap->save(fileName,format.toLatin1(), _conf->getImageQuality());
+        if (format == QLatin1String("jpg"))
+            saved = _pixelMap->save(fileName,format.toLatin1().constData(), _conf->getImageQuality());
         else
-            saved = _pixelMap->save(fileName,format.toLatin1(), -1);
+            saved = _pixelMap->save(fileName,format.toLatin1().constData(), -1);
 
         if (saved)
         {
@@ -434,12 +443,12 @@ bool Core::writeScreen(QString& fileName, QString& format, bool tmpScreen)
 
 QString Core::copyFileNameToCliipboard(QString file)
 {
-    QString retString = "";
+    QString retString = QLatin1String("");
     switch (_conf->getAutoCopyFilenameOnSaving())
     {
     case Config::nameToClipboardFile:
     {
-        file = file.section('/', -1);
+        file = file.section(QLatin1Char('/'), -1);
         QApplication::clipboard()->setText(file);
         retString = QChar(QChar::LineSeparator) + tr("Name of saved file is copied to the clipboard");
         break;
@@ -479,13 +488,13 @@ void Core::openInExtViewer()
     {
         QString format = _conf->getSaveFormat();
         if (format.isEmpty())
-            format = "png";
+            format = QLatin1String("png");
 
         QString tempFileName = getTempFilename(format);
         writeScreen(tempFileName, format, true);
 
         QString exec;
-        exec = "xdg-open";
+        exec = QLatin1String("xdg-open");
         QStringList args;
         args << tempFileName;
 
@@ -535,25 +544,12 @@ void Core::processCmdLineOpts(const QStringList& arguments)
         if (_cmdLine.isSet(_screenTypeOpts.at(i)))
             _conf->setDefScreenshotType(i);
 
-#ifdef SG_EXT_UPLOADS
-    /// FIXMA - In module interface need add the mthod for geting module cmdLine options
-    const QString UPLOAD_CMD_PARAM = "upload";
-    const QString UPLOAD_CMD_PARAM_SHORT = "u";
-    QCommandLineOption u(QStringList() << UPLOAD_CMD_PARAM_SHORT << UPLOAD_CMD_PARAM);
-
-    if (_cmdLine.isSet(u)) {
-        ModuleUploader *uploader = static_cast<ModuleUploader*>(_modules.getModule(MOD_UPLOADER));
-        connect(uploader, &ModuleUploader::uploadCompleteWithQuit, qApp, &QApplication::quit);
-        uploader->init();
-    } else
-        initWindow();
-#endif
-
+    initWindow();
 }
 
 bool Core::runAsMinimized()
 {
-    return (_cmdLine.isSet("minimized") || _cmdLine.isSet("m"));
+    return (_cmdLine.isSet(QStringLiteral("minimized")) || _cmdLine.isSet(QStringLiteral("m")));
 }
 
 void Core::autoSave()
@@ -565,8 +561,8 @@ void Core::autoSave()
 
 QString Core::getVersionPrintable()
 {
-    QString str = "ScreenGrab: " + qApp->applicationVersion() + QString("\n");
-    str += "Qt: " + QString(qVersion()) + QString("\n");
+    QString str = QStringLiteral("ScreenGrab: ") + qApp->applicationVersion() + QStringLiteral("\n");
+    str += QStringLiteral("Qt: ") + QString::fromLatin1(qVersion()) + QStringLiteral("\n");
     return str;
 }
 
@@ -580,7 +576,7 @@ QByteArray Core::getScreenData()
     QByteArray bytes;
     QBuffer buffer(&bytes);
     buffer.open(QIODevice::WriteOnly);
-    _pixelMap->save(&buffer, _conf->getSaveFormat().toLatin1());
+    _pixelMap->save(&buffer, _conf->getSaveFormat().toLatin1().constData());
     return bytes;
 }
 
