@@ -29,9 +29,9 @@ AboutDialog::AboutDialog(QWidget *parent):
     setWindowFlags(Qt::Dialog |  Qt::CustomizeWindowHint | Qt::WindowTitleHint | Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
 
     _ui->setupUi(this);
-    _ui->labAppName->setText(_ui->labAppName->text() + QString(" <b>") + qApp->applicationVersion() + QString("</b>"));
+    _ui->labAppName->setText(_ui->labAppName->text() + QStringLiteral(" <b>") + qApp->applicationVersion() + QStringLiteral("</b>"));
 
-    _ui->labQtVer->setText(tr("using Qt ") + qVersion());
+    _ui->labQtVer->setText(tr("using Qt ") + QString::fromUtf8(qVersion()));
 
     QTabBar *tabs = new QTabBar;
 
@@ -96,19 +96,19 @@ void AboutDialog::on_butClose_clicked()
 QString AboutDialog::tabAbout()
 {
     QString str;
-    str += "<b>ScreenGrab</b> ";
+    str += QLatin1String("<b>ScreenGrab</b> ");
     str += tr("is a crossplatform application for fast creating screenshots of your desktop.");
-    str += "<br><br>";
+    str += QLatin1String("<br><br>");
     str += tr("It is a light and powerful application, written in Qt.");
-    str += "<br><br>";
+    str += QLatin1String("<br><br>");
 
-    str += tr("Website")+" - ";
-    str += "<a href=\"https://github.com/lxqt/screengrab\">https://github.com/lxqt/screengrab</a>";
-    str += "<br><br>";
+    str += tr("Website")+QLatin1String(" - ");
+    str += QLatin1String("<a href=\"https://github.com/lxqt/screengrab\">https://github.com/lxqt/screengrab</a>");
+    str += QLatin1String("<br><br>");
 
     str += tr("Licensed under the ");
-    str += " <a href=http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>GPL v2</a>";
-    str += "<br><br>";
+    str += QLatin1String(" <a href=http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>GPL v2</a>");
+    str += QLatin1String("<br><br>");
 
     str += tr("Copyright &copy; 2009-2013, Artem 'DOOMer' Galichkin");
     return str;
@@ -118,19 +118,19 @@ QString AboutDialog::tabHelpUs()
 {
     QString str;
     str += tr("You can join us and help us if you want. This is an invitation if you like this application.");
-    str += "<br><br>";
+    str += QLatin1String("<br><br>");
 
     str += tr("What you can do?");
 
-    str += "<ul>";
-    str += "<li>" + tr("Translate ScreenGrab to other languages") + "</li>";
-    str += "<li>" + tr("Make suggestions for next releases") + "</li>";
-    str += "<li>" + tr("Report bugs and issues") + "</li>";
-    str += "</ul>";
+    str += QLatin1String("<ul>");
+    str += QLatin1String("<li>") + tr("Translate ScreenGrab to other languages") + QLatin1String("</li>");
+    str += QLatin1String("<li>") + tr("Make suggestions for next releases") + QLatin1String("</li>");
+    str += QLatin1String("<li>") + tr("Report bugs and issues") + QLatin1String("</li>");
+    str += QLatin1String("</ul>");
 
     str += tr("Bug tracker");
-    str += "<br>";
-    str += "<a href=https://github.com/lxqt/screengrab/issues>https://github.com/lxqt/screengrab/issues/</a>";
+    str += QLatin1String("<br>");
+    str += QLatin1String("<a href=https://github.com/lxqt/screengrab/issues>https://github.com/lxqt/screengrab/issues/</a>");
 
     return str;
 }
@@ -138,28 +138,28 @@ QString AboutDialog::tabHelpUs()
 QString AboutDialog::tabThanks()
 {
     QString str;
-    str += "<b>" + tr("Translate:") + "</b>";
-    str += "<br>";
-    str += tr(" Brazilian Portuguese translation")  + "<br>";
-    str += tr("Marcio Moraes") + " &lt;marciopanto@gmail.com&gt;<br>";
-    str += "<br>";
-    str += tr(" Ukrainian translation") + "<br>";
-    str += tr("Gennadi Motsyo") + " &lt;drool@altlinux.ru&gt;<br>";
-    str += "<br>";
-    str += tr(" Spanish translation") + "<br>";
-    str += tr("Burjans L García D") + " &lt;burjans@gmail.com&gt;<br>";
-    str += "<br>";
-    str += tr(" Italian translation") + "<br>";
-    str += "speps &lt;dreamspepser@yahoo.it&gt;<br>";
-    str += "<br>";
+    str += QLatin1String("<b>") + tr("Translate:") + QLatin1String("</b>");
+    str += QLatin1String("<br>");
+    str += tr(" Brazilian Portuguese translation")  + QLatin1String("<br>");
+    str += tr("Marcio Moraes") + QLatin1String(" &lt;marciopanto@gmail.com&gt;<br>");
+    str += QLatin1String("<br>");
+    str += tr(" Ukrainian translation") + QLatin1String("<br>");
+    str += tr("Gennadi Motsyo") + QLatin1String(" &lt;drool@altlinux.ru&gt;<br>");
+    str += QLatin1String("<br>");
+    str += tr(" Spanish translation") + QLatin1String("<br>");
+    str += tr("Burjans L García D") + QLatin1String(" &lt;burjans@gmail.com&gt;<br>");
+    str += QLatin1String("<br>");
+    str += tr(" Italian translation") + QLatin1String("<br>");
+    str += QLatin1String("speps &lt;dreamspepser@yahoo.it&gt;<br>");
+    str += QLatin1String("<br>");
 
-    str += "<b>" + tr("Testing:") + "</b>";
-    str += "<br>";
-    str += "Jerome Leclanche - " + tr("Dual monitor support and other in Linux") + "<br>";
-    str += "Alexander Sokolov - " + tr("Dual monitor support in Linux") + "<br>";
-    str += "Alexantia - " + tr("win32-build [Windows XP and 7]") + "<br>";
-    str += "iNight - " + tr("old win32-build [Windows Vista]") + "<br>";
-    str += "burjans - " + tr("win32-build [Windows 7]") + "<br>";
+    str += QLatin1String("<b>") + tr("Testing:") + QLatin1String("</b>");
+    str += QLatin1String("<br>");
+    str += QLatin1String("Jerome Leclanche - ") + tr("Dual monitor support and other in Linux") + QLatin1String("<br>");
+    str += QLatin1String("Alexander Sokolov - ") + tr("Dual monitor support in Linux") + QLatin1String("<br>");
+    str += QLatin1String("Alexantia - ") + tr("win32-build [Windows XP and 7]") + QLatin1String("<br>");
+    str += QLatin1String("iNight - ") + tr("old win32-build [Windows Vista]") + QLatin1String("<br>");
+    str += QLatin1String("burjans - ") + tr("win32-build [Windows 7]") + QLatin1String("<br>");
 
     return str;
 }
