@@ -22,10 +22,6 @@
 #include "ui_configwidget.h"
 #include "../core.h"
 
-#ifdef SG_GLOBAL_SHORTCUTS
-#include <QxtGui/QxtGlobalShortcut>
-#endif
-
 #include <QDir>
 #include <QFileDialog>
 #include <QMessageBox>
@@ -86,25 +82,11 @@ ConfigDialog::ConfigDialog(QWidget *parent) :
     QTreeWidgetItemIterator iter(_ui->treeKeys);
     while (*iter)
     {
-        if ((*iter)->parent() != NULL)
+        if ((*iter)->parent() != nullptr)
         {
             (*iter)->setData(1, Qt::DisplayRole, conf->shortcuts()->getShortcut(action));
-
-#ifndef SG_GLOBAL_SHORTCUTS
-            if (conf->shortcuts()->getShortcutType(action) == Config::globalShortcut)
-                (*iter)->setHidden(true);
-#endif
             ++action;
         }
-        else
-        {
-#ifndef SG_GLOBAL_SHORTCUTS
-            int numGlobalShortcuts = conf->shortcuts()->getShortcutsList(Config::globalShortcut).count();
-            if ((*iter)->childCount() == numGlobalShortcuts)
-                (*iter)->setHidden(true);
-#endif
-        }
-
         ++iter;
     }
 
@@ -119,7 +101,7 @@ ConfigDialog::ConfigDialog(QWidget *parent) :
     {
         AbstractModule* currentModule = Core::instance()->modules()->getModule(i);
 
-        if (currentModule->initConfigWidget() != 0)
+        if (currentModule->initConfigWidget() != nullptr)
         {
             _ui->listWidget->addItem(currentModule->moduleName());
             QWidget *currentModWidget = currentModule->initConfigWidget();
@@ -132,9 +114,8 @@ ConfigDialog::ConfigDialog(QWidget *parent) :
 ConfigDialog::~ConfigDialog()
 {
     delete _ui;
-    conf = NULL;
+    conf = nullptr;
     delete conf;
-
 }
 
 void ConfigDialog::loadSettings()
@@ -198,7 +179,7 @@ void ConfigDialog::changeFormatType(int type)
 
 void ConfigDialog::changeImgQualituSlider(int pos)
 {
-    QString text = " " + QString::number(pos) + "%";
+    QString text = QLatin1Char(' ') + QString::number(pos) + QLatin1Char('%');
     _ui->labImgQualityCurrent->setText(text);
 }
 
@@ -209,7 +190,7 @@ void ConfigDialog::saveSettings()
     {
         QMessageBox msg;
         msg.setText(tr("Directory %1 does not exist. Do you want to create it?").arg(QDir::toNativeSeparators(screenshotDir.path()) + QDir::separator()));
-        msg.setWindowTitle("ScreenGrab" + QString(" - ") + tr("Warning"));
+        msg.setWindowTitle(QStringLiteral("ScreenGrab") + QStringLiteral(" - ") + tr("Warning"));
         msg.setIcon(QMessageBox::Question);
         msg.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
 
@@ -290,9 +271,9 @@ QString ConfigDialog::getFormat()
 {
     switch (_ui->cbxFormat->currentIndex())
     {
-        case 0: return "png";
-        case 1: return "jpg";
-        default: return "png";
+        case 0: return QStringLiteral("png");
+        case 1: return QStringLiteral("jpg");
+        default: return QStringLiteral("png");
     }
 }
 
@@ -310,7 +291,7 @@ void ConfigDialog::restoreDefaults()
 {
     QMessageBox msg;
     msg.setText(tr("Do you want to reset the settings to the defaults?"));
-    msg.setWindowTitle("ScreenGrab" + QString(" - ") + tr("Warning"));
+    msg.setWindowTitle(QStringLiteral("ScreenGrab") + QStringLiteral(" - ") + tr("Warning"));
     msg.setIcon(QMessageBox::Question);
     msg.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
 
@@ -364,9 +345,9 @@ void ConfigDialog::setVisibleDateTplEdit(bool checked)
     }
 }
 
-void ConfigDialog::editDateTmeTpl(QString str)
+void ConfigDialog::editDateTmeTpl(const QString &str)
 {
-    QString currentDateTime = QDateTime::currentDateTime().toString(str );
+    QString currentDateTime = QDateTime::currentDateTime().toString(str);
     _ui->labMaskExample->setText(tr("Example: ") + currentDateTime);
 }
 
@@ -419,16 +400,9 @@ void ConfigDialog::acceptShortcut(const QKeySequence& seq)
 {
     if (!checkUsedShortcuts())
     {
-#ifdef SG_GLOBAL_SHORTCUTS
-        if (avalibelGlobalShortcuts(seq))
-            changeShortcut(seq);
-        else
-            showErrorMessage(tr("This key is already used in your system! Please select another."));
-#else
-    changeShortcut(seq);
-#endif
+        changeShortcut(seq);
     }
-    else if (checkUsedShortcuts() && seq.toString() != "")
+    else if (checkUsedShortcuts() && !seq.toString().isEmpty())
         showErrorMessage(tr("This key is already used in ScreenGrab! Please select another."));
 }
 
@@ -442,7 +416,7 @@ void ConfigDialog::changeShortcut(const QKeySequence& seq)
 void ConfigDialog::clearShrtcut()
 {
     QTreeWidgetItem *item = _ui->treeKeys->selectedItems().first();
-    item->setData(1, Qt::DisplayRole, QString(""));
+    item->setData(1, Qt::DisplayRole, QLatin1String(""));
 }
 
 void ConfigDialog::keyNotSupported()
@@ -463,22 +437,7 @@ bool ConfigDialog::checkUsedShortcuts()
     return false;
 }
 
-#ifdef SG_GLOBAL_SHORTCUTS
-bool ConfigDialog::avalibelGlobalShortcuts(const QKeySequence& seq)
-{
-    bool ok = false;
-    QxtGlobalShortcut *tmpShortcut = new QxtGlobalShortcut;
-    if (tmpShortcut->setShortcut(QKeySequence(seq)) == true)
-    {
-        tmpShortcut->setDisabled(true);
-        ok = true;
-    }
-    delete tmpShortcut;
-    return ok;
-}
-#endif
-
-void ConfigDialog::showErrorMessage(QString text)
+void ConfigDialog::showErrorMessage(const QString &text)
 {
     _ui->keyWidget->clearKeySequence();
     QMessageBox msg;
