@@ -19,6 +19,8 @@
 #include "extedit.h"
 #include "core/core.h"
 
+#include <XdgMimeApps>
+
 #include <QDebug>
 #include <QMimeDatabase>
 
@@ -42,7 +44,7 @@ void ExtEdit::runExternalEditor()
     Core *core = Core::instance();
     QString format = core->config()->getSaveFormat();
     if (format.isEmpty())
-        format = "png";
+        format = QLatin1String("png");
 
     _editFilename = core->getTempFilename(format);
     core->writeScreen(_editFilename, format, true);
@@ -81,12 +83,13 @@ void ExtEdit::createAppList()
     Core *core = Core::instance();
     QString format = core->config()->getSaveFormat();
     if (format.isEmpty())
-        format = "png";
+        format = QLatin1String("png");
 
     QString fileName = _editFilename.isEmpty() ? core->getTempFilename(format) : _editFilename;
     QMimeDatabase db;
+    XdgMimeApps mimeAppsDb;
     QMimeType mt = db.mimeTypeForFile(fileName);
-    _appList = XdgDesktopFileCache::getApps(mt.name());
+    _appList = mimeAppsDb.apps(mt.name());
 
     for (XdgDesktopFile *app : qAsConst(_appList))
         _actionList << new XdgAction(app);
